@@ -1,6 +1,4 @@
 from .ListingResource import ListingResource
 from .ReceiptResource import ReceiptResource
 from .ReviewResource import ReviewResource
-from .ShopResource import ShopResource
-from .TransactionResource import TransactionResource
-from ..models import Listing
\ No newline at end of file
+from .ShopResource import ShopResource
\ No newline at end of file
